@@ -2,10 +2,10 @@
 /*
  * gsf-output-gnomevfs.h: gnomevfs based output
  *
- * Copyright (C) 2002 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2002-2003 Dom Lachowicz (cinamod@hotmail.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -34,8 +34,8 @@ G_BEGIN_DECLS
 typedef struct _GsfOutputGnomeVFS GsfOutputGnomeVFS;
 
 GType      gsf_output_gnomevfs_get_type (void);
-GsfOutput *gsf_output_gnomevfs_new      (char const *filename, GError **err);
-GsfOutput *gsf_output_gnomevfs_new_uri  (GnomeVFSURI * uri, GError **err);
+GsfOutputGnomeVFS *gsf_output_gnomevfs_new      (char const *filename, GError **err);
+GsfOutputGnomeVFS *gsf_output_gnomevfs_new_uri  (GnomeVFSURI * uri, GError **err);
 
 G_END_DECLS
 
