@@ -1,11 +1,11 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gsf-meta_data-bag.h: get, set, remove custom meta properties associated with documents
+ * gsf-doc-meta-data.h: get, set, remove custom meta properties associated with documents
  *
- * Copyright (C) 2002 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2002-2003 Dom Lachowicz (cinamod@hotmail.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -27,6 +27,9 @@
 
 G_BEGIN_DECLS
 
+/* THIS IS A WORK IN PROGRESS
+ * API will change when we start using it */
+
 struct _GsfDocProp {
 	char const *name;
 	GValue *val;
@@ -41,11 +44,11 @@ GType  gsf_doc_meta_data_get_type (void);
 GQuark gsf_doc_meta_data_error (void);
 
 GsfDocMetaData	 *gsf_doc_meta_data_new		(void);
-GsfDocProp const *gsf_doc_meta_data_get_prop	(GsfDocMetaData *meta, char const *prop_name);
+GsfDocProp const *gsf_doc_meta_data_get_prop	(GsfDocMetaData const *meta, char const *prop_name);
 void		  gsf_doc_meta_data_set_prop	(GsfDocMetaData *meta, GsfDocProp *prop);
 void		  gsf_doc_meta_data_remove_prop	(GsfDocMetaData *meta, char const *prop);
-void		  gsf_doc_meta_data_foreach	(GsfDocMetaData *meta, GHFunc func, gpointer user_data);
-int		  gsf_doc_meta_data_size	(GsfDocMetaData *meta);
+void		  gsf_doc_meta_data_foreach	(GsfDocMetaData const *meta, GHFunc func, gpointer user_data);
+gsize		  gsf_doc_meta_data_size	(GsfDocMetaData const *meta);
 
 G_END_DECLS
 
