@@ -46,6 +46,7 @@ typedef struct {
 	guint32   first_block;
 	gboolean  is_directory;
 	GList	 *children;
+	unsigned char clsid[16];	/* 16 byte GUID used by some apps */
 } MSOleDirent;
 
 typedef struct {
@@ -55,7 +56,7 @@ typedef struct {
 		unsigned filter;
 		size_t   size;
 	} bb, sb;
-	unsigned max_block;
+	gsf_off_t max_block;
 	guint32 threshold; /* transition between small and big blocks */
         guint32 sbat_start, num_sbat;
 
@@ -72,7 +73,7 @@ struct _GsfInfileMSOle {
 	MSOleInfo   *info;
 	MSOleDirent *dirent;
 	MSOleBAT     bat;
-	guint32	     cur_block;
+	gsf_off_t    cur_block;
 
 	struct {
 		guint8  *buf;
@@ -91,7 +92,7 @@ typedef struct {
 #define OLE_BIG_BLOCK(index, ole)	((index) >> ole->info->bb.shift)
 
 static GsfInput *gsf_infile_msole_new_child (GsfInfileMSOle *parent,
-					     MSOleDirent *dirent);
+					     MSOleDirent *dirent, GError **err);
 static void ole_info_unref (MSOleInfo *info);
 
 /**
@@ -108,8 +109,10 @@ ole_get_block (GsfInfileMSOle const *ole, guint32 block, guint8 *buffer)
 {
 	g_return_val_if_fail (block < ole->info->max_block, NULL);
 
+	/* OLE_HEADER_SIZE is fixed at 512, but the sector containing the
+	 * header is padded out to bb.size (sector size) when bb.size > 512. */
 	if (gsf_input_seek (ole->input,
-		(gsf_off_t)(OLE_HEADER_SIZE + (block << ole->info->bb.shift)),
+		(gsf_off_t)(MAX (OLE_HEADER_SIZE, ole->info->bb.size) + (block << ole->info->bb.shift)),
 		G_SEEK_SET) < 0)
 		return NULL;
 
@@ -118,7 +121,6 @@ ole_get_block (GsfInfileMSOle const *ole, guint32 block, guint8 *buffer)
 
 /**
  * ole_make_bat :
- * @info	: the general descriptor
  * @metabat	: a meta bat to connect to the raw blocks (small or large)
  * @size_guess	: An optional guess as to how many blocks are in the file
  * @block	: The first block in the list.
@@ -151,10 +153,17 @@ ole_make_bat (MSOleBAT const *metabat, size_t size_guess, guint32 block,
 		} while (block < metabat->num_blocks);
 
 	res->block = NULL;
-	g_return_val_if_fail (block == BAT_MAGIC_END_OF_CHAIN, TRUE);
 
 	res->num_blocks = bat->len;
 	res->block = (guint32 *) (gpointer) g_array_free (bat, FALSE);
+
+	if (block != BAT_MAGIC_END_OF_CHAIN) {
+		g_warning ("This OLE2 file is invalid.\n"
+			   "The Block Allocation  Table for one of the streams had %x instead of a terminator (%x).\n"
+			   "We might still be able to extract some data, but you'll want to check the file.",
+			   block, BAT_MAGIC_END_OF_CHAIN);
+	}
+
 	return FALSE;
 }
 
@@ -222,7 +231,7 @@ ole_info_get_sb_file (GsfInfileMSOle *parent)
 		return parent->info->sb_file;
 
 	parent->info->sb_file = gsf_infile_msole_new_child (parent,
-		parent->info->root_dir);
+		parent->info->root_dir, NULL);
 
 	/* avoid creating a circular reference */
 	ole_info_unref (((GsfInfileMSOle *)parent->info->sb_file)->info);
@@ -299,6 +308,9 @@ ole_dirent_new (GsfInfileMSOle *ole, guint32 entry, MSOleDirent *parent)
 	dirent = g_new0 (MSOleDirent, 1);
 	dirent->index	     = entry;
 	dirent->size	     = size;
+	/* Store the class id which is 16 byte identifier used by some apps */
+	memcpy(dirent->clsid, data + DIRENT_CLSID, sizeof(dirent->clsid));
+
 	/* root dir is always big block */
 	dirent->use_sb	     = parent && (size < ole->info->threshold);
 	dirent->first_block  = (GSF_LE_GET_GUINT32 (data + DIRENT_FIRSTBLOCK));
@@ -415,14 +427,19 @@ ole_info_ref (MSOleInfo *info)
  * Return value: the partial duplicate.
  **/
 static GsfInfileMSOle *
-ole_dup (GsfInfileMSOle const *src)
+ole_dup (GsfInfileMSOle const *src, GError **err)
 {
 	GsfInfileMSOle	*dst;
+	GsfInput *input;
 
 	g_return_val_if_fail (src != NULL, NULL);
 
+	input = gsf_input_dup (src->input, err);
+	if (input == NULL)
+		return NULL;
+
 	dst = g_object_new (GSF_INFILE_MSOLE_TYPE, NULL);
-	dst->input = gsf_input_dup (src->input, NULL);
+	dst->input = input;
 	dst->info  = ole_info_ref (src->info);
 
 	/* buf and buf_size are initialized to NULL */
@@ -603,15 +620,10 @@ static GsfInput *
 gsf_infile_msole_dup (GsfInput *src_input, GError **err)
 {
 	GsfInfileMSOle const *src = GSF_INFILE_MSOLE (src_input);
-	GsfInfileMSOle *dst = ole_dup (src);
+	GsfInfileMSOle *dst = ole_dup (src, err);
 
-	if (dst == NULL) {
-		if (err != NULL)
-			/* FIXME: better message.  */
-			*err = g_error_new (gsf_input_error (), 0,
-				"Something went wrong in ole_dup.");
+	if (dst == NULL)
 		return NULL;
-	}
 
 	if (src->bat.block != NULL) {
 		dst->bat.block = g_new (guint32, src->bat.num_blocks),
@@ -628,10 +640,10 @@ static guint8 const *
 gsf_infile_msole_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 {
 	GsfInfileMSOle *ole = GSF_INFILE_MSOLE (input);
-	guint32 first_block, last_block, raw_block, offset, i;
+	gsf_off_t first_block, last_block, raw_block, offset, i;
 	guint8 const *data;
 	guint8 *ptr;
-	unsigned count;
+	size_t count;
 
 	/* small block files are preload */
 	if (ole->dirent != NULL && ole->dirent->use_sb) {
@@ -653,10 +665,10 @@ gsf_infile_msole_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 	while (++i <= last_block && ++raw_block == ole->bat.block [i])
 		;
 	if (i > last_block) {
-		/* optimization don't see if we don't need to */
+		/* optimization don't seek if we don't need to */
 		if (ole->cur_block != first_block) {
 			if (gsf_input_seek (ole->input,
-				(gsf_off_t)(OLE_HEADER_SIZE + (ole->bat.block [first_block] << ole->info->bb.shift) + offset),
+				(gsf_off_t)(MAX (OLE_HEADER_SIZE, ole->info->bb.size) + (ole->bat.block [first_block] << ole->info->bb.shift) + offset),
 				G_SEEK_SET) < 0)
 				return NULL;
 		}
@@ -706,7 +718,8 @@ gsf_infile_msole_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 }
 
 static GsfInput *
-gsf_infile_msole_new_child (GsfInfileMSOle *parent, MSOleDirent *dirent)
+gsf_infile_msole_new_child (GsfInfileMSOle *parent,
+			    MSOleDirent *dirent, GError **err)
 {
 	GsfInfileMSOle *child;
 	MSOleInfo *info;
@@ -714,7 +727,7 @@ gsf_infile_msole_new_child (GsfInfileMSOle *parent, MSOleDirent *dirent)
 	GsfInput *sb_file = NULL;
 	size_t size_guess;
 
-	child = ole_dup (parent);
+	child = ole_dup (parent, err);
 	child->dirent = dirent;
 	gsf_input_set_size (GSF_INPUT (child), (gsf_off_t) dirent->size);
 
@@ -722,8 +735,13 @@ gsf_infile_msole_new_child (GsfInfileMSOle *parent, MSOleDirent *dirent)
 	if (dirent->index != 0) {
 		gsf_input_set_name (GSF_INPUT (child), dirent->name);
 		gsf_input_set_container (GSF_INPUT (child), GSF_INFILE (parent));
-		if (dirent->is_directory)
+
+		if (dirent->is_directory) {
+			/* be wary.  It seems as if some implementations pretend that the
+			 * directories contain data */
+			gsf_input_set_size (GSF_INPUT (child), 0);
 			return GSF_INPUT (child);
+		}
 	}
 
 	info = parent->info;
@@ -769,14 +787,14 @@ gsf_infile_msole_new_child (GsfInfileMSOle *parent, MSOleDirent *dirent)
 }
 
 static GsfInput *
-gsf_infile_msole_child_by_index (GsfInfile *infile, int target)
+gsf_infile_msole_child_by_index (GsfInfile *infile, int target, GError **err)
 {
 	GsfInfileMSOle *ole = GSF_INFILE_MSOLE (infile);
 	GList *p;
 
 	for (p = ole->dirent->children; p != NULL ; p = p->next)
 		if (target-- <= 0)
-			return gsf_infile_msole_new_child (ole, p->data);
+			return gsf_infile_msole_new_child (ole, p->data, err);
 	return NULL;
 }
 
@@ -793,7 +811,7 @@ gsf_infile_msole_name_by_index (GsfInfile *infile, int target)
 }
 
 static GsfInput *
-gsf_infile_msole_child_by_name (GsfInfile *infile, char const *name)
+gsf_infile_msole_child_by_name (GsfInfile *infile, char const *name, GError **err)
 {
 	GsfInfileMSOle *ole = GSF_INFILE_MSOLE (infile);
 	GList *p;
@@ -801,7 +819,7 @@ gsf_infile_msole_child_by_name (GsfInfile *infile, char const *name)
 	for (p = ole->dirent->children; p != NULL ; p = p->next) {
 		MSOleDirent *dirent = p->data;
 		if (dirent->name != NULL && !strcmp (name, dirent->name))
-			return gsf_infile_msole_new_child (ole, dirent);
+			return gsf_infile_msole_new_child (ole, dirent, err);
 	}
 	return NULL;
 }
@@ -881,3 +899,23 @@ gsf_infile_msole_new (GsfInput *source, GError **err)
 
 	return ole;
 }
+
+/**
+ * gsf_infile_msole_get_class_id :
+ * @ole: a #GsfInfileMSOle
+ * @res: 16 byte identifier (often a GUID in MS Windows apps)
+ *
+ * Retrieves the 16 byte indentifier (often a GUID in MS Windows apps)
+ * stored within the directory associated with @ole and stores it in @res.
+ *
+ * Returns TRUE on success
+ **/
+gboolean
+gsf_infile_msole_get_class_id (GsfInfileMSOle const *ole, guint8 *res)
+{
+	g_return_val_if_fail (ole != NULL && ole->dirent != NULL, FALSE);
+
+	memcpy (res, ole->dirent->clsid,
+		sizeof(ole->dirent->clsid));
+	return TRUE;
+}
