@@ -2,10 +2,10 @@
 /*
  * gsf-infile-msvba.c :
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -239,7 +239,7 @@ vba3_dir_read (GsfInfileMSVBA *vba, GError **err)
 	};
 
 	GsfInput *dir;
-	size_t inflated_size;
+	int inflated_size;
 	guint8 *inflated;
 	unsigned offset, name_len, i, j;
 	char *name;
@@ -437,7 +437,9 @@ gsf_infile_msvba_dup (GsfInput *src_input, GError **err)
 
 	(void) src;
 	(void) err;
+#ifdef __GNUC__
 #warning TODO
+#endif
 	return GSF_INPUT (dst);
 }
 
@@ -458,25 +460,30 @@ gsf_infile_msvba_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 }
 
 static GsfInput *
-gsf_infile_msvba_new_child (GsfInfileMSVBA *parent, MSVBADirent *dirent)
+gsf_infile_msvba_new_child (GsfInfileMSVBA *parent, MSVBADirent *dirent, GError **err)
 {
 	GsfInputMemory *child = NULL;
 
 	(void) parent;
 	(void) dirent;
+	(void) err;
+
+#ifdef __GNUC__
 #warning TODO
+#endif
+
 	return GSF_INPUT (child);
 }
 
 static GsfInput *
-gsf_infile_msvba_child_by_index (GsfInfile *infile, int target)
+gsf_infile_msvba_child_by_index (GsfInfile *infile, int target, GError **err)
 {
 	GsfInfileMSVBA *vba = GSF_INFILE_MSVBA (infile);
 	GList *p;
 
 	for (p = vba->children; p != NULL ; p = p->next)
 		if (target-- <= 0)
-			return gsf_infile_msvba_new_child (vba, p->data);
+			return gsf_infile_msvba_new_child (vba, p->data, err);
 	return NULL;
 }
 
@@ -493,7 +500,7 @@ gsf_infile_msvba_name_by_index (GsfInfile *infile, int target)
 }
 
 static GsfInput *
-gsf_infile_msvba_child_by_name (GsfInfile *infile, char const *name)
+gsf_infile_msvba_child_by_name (GsfInfile *infile, char const *name, GError **err)
 {
 	GsfInfileMSVBA *vba = GSF_INFILE_MSVBA (infile);
 	GList *p;
@@ -501,7 +508,7 @@ gsf_infile_msvba_child_by_name (GsfInfile *infile, char const *name)
 	for (p = vba->children; p != NULL ; p = p->next) {
 		MSVBADirent *dirent = p->data;
 		if (dirent->name != NULL && !strcmp (name, dirent->name))
-			return gsf_infile_msvba_new_child (vba, dirent);
+			return gsf_infile_msvba_new_child (vba, dirent, err);
 	}
 	return NULL;
 }
@@ -543,7 +550,7 @@ GSF_CLASS (GsfInfileMSVBA, gsf_infile_msvba,
 	   gsf_infile_msvba_class_init, gsf_infile_msvba_init,
 	   GSF_INFILE_TYPE)
 
-GsfInfile *
+GsfInfileMSVBA *
 gsf_infile_msvba_new (GsfInfile *source, GError **err)
 {
 	GsfInfileMSVBA *vba;
@@ -557,7 +564,7 @@ gsf_infile_msvba_new (GsfInfile *source, GError **err)
 
 	/* find the name offset pairs */
 	if (vba56_dir_read (vba, err) || vba3_dir_read (vba, err))
-		return GSF_INFILE (vba);
+		return vba;
 
 	if (err != NULL && *err == NULL) {
 		*err = g_error_new (gsf_input_error (), 0,
