@@ -2,10 +2,10 @@
 /*
  * gsf-input-gzip.c: wrapper to uncompress gzipped input
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -228,7 +228,7 @@ gsf_input_gzip_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 			gzip->buf_size = MAX (num_bytes, 256);
 			if (gzip->buf != NULL)
 				g_free (gzip->buf);
-			gzip->buf = g_malloc (gzip->buf_size);
+			gzip->buf = g_new (guint8, gzip->buf_size);
 		}
 		buffer = gzip->buf;
 	}
@@ -253,8 +253,13 @@ gsf_input_gzip_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 			gzip->stream.next_in = (Byte *)gzip->gzipped_data;
 		}
 		zerr = inflate (&(gzip->stream), Z_NO_FLUSH);
-		if (zerr != Z_OK && zerr != Z_STREAM_END)
-			return NULL;
+		if (zerr != Z_OK) {
+			if (zerr != Z_STREAM_END)
+				return NULL;
+			/* Premature end of stream.  */
+			if (gzip->stream.avail_out != 0)
+				return NULL;
+		}
 	}
 
 	gzip->crc = crc32 (gzip->crc, buffer, (uInt)(gzip->stream.next_out - buffer));
