@@ -2,10 +2,10 @@
 /*
  * gsf-input-memory.h: interface for used by the ole layer to read raw data
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -33,17 +33,10 @@ G_BEGIN_DECLS
 typedef struct _GsfInputMemory GsfInputMemory;
 
 GType     gsf_input_memory_get_type (void);
-GsfInput *gsf_input_memory_new      (guint8 const *buf, gsf_off_t length,
-				     gboolean needs_free);
-
-#define GSF_INPUT_MMAP_TYPE	(gsf_input_mmap_get_type ())
-#define GSF_INPUT_MMAP(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GSF_INPUT_MMAP_TYPE, GsfInputMMap))
-#define GSF_IS_INPUT_MMAP(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GSF_INPUT_MMAP_TYPE))
-
-typedef struct _GsfInputMMap GsfInputMMap;
-
-GType     gsf_input_mmap_get_type (void);
-GsfInput *gsf_input_mmap_new	  (char const *filename, GError **err);
+GsfInputMemory *gsf_input_memory_new      (guint8 const *buf, gsf_off_t length,
+					   gboolean needs_free);
+GsfInputMemory *gsf_input_memory_new_clone (guint8 const *buf, gsf_off_t length);
+GsfInputMemory *gsf_input_mmap_new	  (char const *filename, GError **err);
 
 G_END_DECLS
 
