@@ -2,10 +2,10 @@
 /*
  * gsf-input-stdio.c: stdio based input
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -27,10 +27,16 @@
 
 #include <stdio.h>
 #include <errno.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#ifdef _MSC_VER
+#define S_ISREG(x) ((x) & _S_IFREG)
+#endif
+
 struct _GsfInputStdio {
 	GsfInput input;
 
@@ -50,7 +56,7 @@ typedef struct {
  *
  * Returns a new file or NULL.
  **/
-GsfInput *
+GsfInputStdio *
 gsf_input_stdio_new (char const *filename, GError **err)
 {
 	GsfInputStdio *input;
@@ -89,7 +95,7 @@ gsf_input_stdio_new (char const *filename, GError **err)
 	gsf_input_set_size (GSF_INPUT (input), size);
 	gsf_input_set_name (GSF_INPUT (input), filename);
 
-	return GSF_INPUT (input);
+	return input;
 }
 
 static void
@@ -117,7 +123,7 @@ static GsfInput *
 gsf_input_stdio_dup (GsfInput *src_input, GError **err)
 {
 	GsfInputStdio const *src = (GsfInputStdio *)src_input;
-	return gsf_input_stdio_new (src->input.name, err);
+	return GSF_INPUT (gsf_input_stdio_new (src->input.name, err));
 }
 
 static guint8 const *
@@ -135,7 +141,7 @@ gsf_input_stdio_read (GsfInput *input, size_t num_bytes,
 			stdio->buf_size = num_bytes;
 			if (stdio->buf != NULL)
 				g_free (stdio->buf);
-			stdio->buf = g_malloc (stdio->buf_size);
+			stdio->buf = g_new (guint8, stdio->buf_size);
 		}
 		buffer = stdio->buf;
 	}
@@ -156,7 +162,7 @@ static gboolean
 gsf_input_stdio_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 {
 	GsfInputStdio const *stdio = GSF_INPUT_STDIO (input);
-	long loffset;
+	gsf_off_t loffset;
 	int stdio_whence = SEEK_SET;
 
 	if (stdio->file == NULL)
@@ -175,7 +181,7 @@ gsf_input_stdio_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 		break;
 	}
 
-	if (0 == fseek (stdio->file, loffset, stdio_whence))
+	if (0 == fseek (stdio->file, (unsigned long)loffset, stdio_whence))
 		return FALSE;
 	
 	return TRUE;
