@@ -2,10 +2,10 @@
 /*
  * gsf-input.c: interface for used by the ole layer to read raw data
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -25,8 +25,66 @@
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
+#ifdef HAVE_BZIP
+#include <gsf/gsf-input-bzip.h>
+#endif
+
 #define GET_CLASS(instance) G_TYPE_INSTANCE_GET_CLASS (instance, GSF_INPUT_TYPE, GsfInputClass)
 
+enum {
+	PROP_0,
+	PROP_NAME,
+	PROP_SIZE,
+	PROP_EOF,
+	PROP_REMAINING,
+	PROP_POS
+};
+
+#if 0
+static void
+gsf_input_set_property (GObject      *object,
+			guint         property_id,
+			GValue const *value,
+			GParamSpec   *pspec)
+{
+	switch (property_id)
+		{
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+			break;
+		}
+}
+#endif
+
+static void
+gsf_input_get_property (GObject     *object,
+			guint        property_id,
+			GValue      *value,
+			GParamSpec  *pspec)
+{
+	/* gsf_off_t is typedef'd to gint64 */
+	switch (property_id) {
+	case PROP_NAME:
+		g_value_set_string (value, gsf_input_name (GSF_INPUT (object)));
+		break;
+	case PROP_SIZE:
+		g_value_set_int64 (value, gsf_input_size (GSF_INPUT (object)));
+		break;
+	case PROP_EOF:
+		g_value_set_boolean (value, gsf_input_eof (GSF_INPUT (object)));
+		break;
+	case PROP_REMAINING:
+		g_value_set_int64 (value, gsf_input_remaining (GSF_INPUT (object)));
+		break;
+	case PROP_POS:
+		g_value_set_int64 (value, gsf_input_tell (GSF_INPUT (object)));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
 static void
 gsf_input_finalize (GObject *obj)
 {
@@ -61,7 +119,35 @@ gsf_input_init (GObject *obj)
 static void
 gsf_input_class_init (GObjectClass *gobject_class)
 {
-	gobject_class->finalize = gsf_input_finalize;
+	gobject_class->finalize     = gsf_input_finalize;
+	/* gobject_class->set_property = gsf_input_set_property; */
+	gobject_class->get_property = gsf_input_get_property;
+
+	g_object_class_install_property (gobject_class,
+					 PROP_NAME,
+					 g_param_spec_pointer ("name", "Name",
+							       "The Input's Name",
+							       G_PARAM_READABLE));
+	g_object_class_install_property (gobject_class,
+					 PROP_SIZE,
+					 g_param_spec_pointer ("size", "Size",
+							       "The Input's Size",
+							       G_PARAM_READABLE));
+	g_object_class_install_property (gobject_class,
+					 PROP_EOF,
+					 g_param_spec_pointer ("eof", "OEF",
+							       "End Of File",
+							       G_PARAM_READABLE));
+	g_object_class_install_property (gobject_class,
+					 PROP_REMAINING,
+					 g_param_spec_pointer ("remaining", "Remaining",
+							       "Amount of Data Remaining",
+							       G_PARAM_READABLE));
+	g_object_class_install_property (gobject_class,
+					 PROP_POS,
+					 g_param_spec_pointer ("position", "Position",
+							       "The Output's Current Position",
+							       G_PARAM_READABLE));
 }
 
 GSF_CLASS_ABSTRACT (GsfInput, gsf_input,
@@ -227,7 +313,7 @@ gsf_input_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 {
 	gsf_off_t pos = offset;
 
-	g_return_val_if_fail (input != NULL, -1);
+	g_return_val_if_fail (input != NULL, TRUE);
 
 	switch (whence) {
 	case G_SEEK_SET : break;
@@ -325,7 +411,7 @@ gsf_input_seek_emulate (GsfInput *input, gsf_off_t pos)
 		return TRUE;
 
 	while (pos > input->cur_offset) {
-		size_t readcount = MIN (pos - input->cur_offset, 8192);
+		gsf_off_t readcount = MIN (pos - input->cur_offset, 8192);
 		if (!gsf_input_read (input, readcount, NULL))
 			return TRUE;
 	}
@@ -369,14 +455,14 @@ gboolean
 gsf_input_copy (GsfInput *input, GsfOutput *output)
 {
 	gsf_off_t    remaining = 0;
-	size_t       toread    = 0;
-	const guint8 * buffer    = NULL;
+	gsf_off_t    toread    = 0;
+	const guint8 * buffer  = NULL;
 	gboolean     success   = TRUE;
 
 	g_return_val_if_fail (input != NULL, FALSE);
 	g_return_val_if_fail (output != NULL, FALSE);
 
-	while ((remaining = gsf_input_remaining (input)) > 0 && (success == TRUE)) {
+	while ((remaining = gsf_input_remaining (input)) > 0 && (success)) {
 		toread = MIN (remaining, GSF_READ_BUFSIZE);
 		if (NULL == (buffer = gsf_input_read (input, toread, NULL)))
 			success = FALSE;
@@ -420,12 +506,27 @@ gsf_input_uncompress (GsfInput *src)
 
 		if (memcmp (gzip_sig, data, sizeof (gzip_sig)) == 0) {
 			GsfInputGZip *res = gsf_input_gzip_new (src, NULL);
+			if (res) {
+				g_object_unref (G_OBJECT (src));
+				return gsf_input_uncompress (GSF_INPUT (res));
+			} 
+		}
+	}
+
+#ifdef HAVE_BZIP
+	/* Let's try bzip.  */
+	{
+		const guint8 * bzip_sig = "BZh";
+
+		if (memcmp (gzip_sig, data, strlen (bzip_sig)) == 0) {
+			GsfInputMemory *res = gsf_input_memory_new_from_bzip (src, NULL);
 			if (res) {
 				g_object_unref (G_OBJECT (src));
 				return gsf_input_uncompress (GSF_INPUT (res));
 			}
 		}
 	}
+#endif
 
 	/* Other methods go here.  */
 
@@ -433,3 +534,43 @@ gsf_input_uncompress (GsfInput *src)
 	(void)gsf_input_seek (src, cur_offset, G_SEEK_SET);
 	return src;
 }
+
+#if 0
+
+#include <gsf/gsf-input-stdio.h>
+
+#ifdef HAVE_GNOME
+#include <gsf-gnome/gsf-input-gnomevfs.h>
+#endif
+
+GsfInput*
+gsf_input_new_for_uri (char const * uri, GError ** err)
+{
+	GsfInput * input = NULL;
+	size_t len;
+
+	g_return_val_if_fail (uri, NULL);
+
+	len = strlen (uri);
+	g_return_val_if_fail (len, NULL);
+
+	if (len > 3 && !strstr (uri, ":/")) {
+		/* assume plain file */
+		input = GSF_INPUT (gsf_input_stdio_new (uri, err));
+	} else {
+#if HAVE_GNOME
+		/* have gnome, let GnomeVFS deal with this */
+		input = GSF_INPUT (gsf_input_gnomevfs_new (uri, err));
+#else		
+		if (len > 7 && !strncmp (uri, "file:/", 6)) {
+			/* dumb attempt to translate this into a local path */
+			input = GSF_INPUT (gsf_input_stdio_new (uri+7, err));			
+		} 
+		/* else: unknown or unhandled protocol - bail */
+#endif
+	}
+
+	return input;
+}
+
+#endif
