@@ -2,10 +2,10 @@
 /*
  * gsf-input.h: interface for used by the ole layer to read raw data
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -25,6 +25,7 @@
 #include <gsf/gsf.h>
 #include <glib-object.h>
 #include <sys/types.h>
+#include <gsf/gsf-output.h>
 
 G_BEGIN_DECLS
 
@@ -46,6 +47,8 @@ gsf_off_t     gsf_input_remaining (GsfInput *input);
 gsf_off_t     gsf_input_tell	  (GsfInput *input);
 gboolean      gsf_input_seek	  (GsfInput *input,
 				   gsf_off_t offset, GSeekType whence);
+gboolean      gsf_input_copy      (GsfInput *input,
+				   GsfOutput *output);
 
 GsfInput *gsf_input_uncompress (GsfInput *src);
 
