@@ -34,6 +34,12 @@
 
 typedef enum { MSOLE_DIR, MSOLE_SMALL_BLOCK, MSOLE_BIG_BLOCK } MSOleOutfileType;
 
+/* The most common values */
+#define OLE_DEFAULT_THRESHOLD	 0x1000
+#define OLE_DEFAULT_BB_SIZE	 (1 << OLE_DEFAULT_BB_SHIFT)
+#define OLE_DEFAULT_SB_SIZE	 (1 << OLE_DEFAULT_SB_SHIFT)
+#define OLE_DEFAULT_METABAT_SIZE ((1 << (OLE_DEFAULT_BB_SHIFT - 2)) - 1)
+
 struct _GsfOutfileMSOle {
 	GsfOutfile parent;
 
@@ -45,6 +51,11 @@ struct _GsfOutfileMSOle {
 	unsigned	 blocks;
 	unsigned	 child_index;
 
+	struct {
+		unsigned shift;
+		unsigned size;
+	} bb, sb;
+
 	union {
 		struct {
 			GSList 	  *children;
@@ -57,14 +68,9 @@ struct _GsfOutfileMSOle {
 			size_t  start_offset;	/* in bytes */
 		} big_block;
 	} content;
+	unsigned char clsid[16];		/* 16 byte GUID used by some apps */
 };
-
-typedef struct {
-	GsfOutfileClass  parent_class;
-} GsfOutfileMSOleClass;
-
-#define GSF_OUTFILE_MSOLE_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST ((k), GSF_OUTFILE_MSOLE_TYPE, GsfOutfileMSOleClass))
-#define GSF_IS_OUTFILE_MSOLE_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GSF_OUTFILE_MSOLE_TYPE))
+typedef GsfOutfileClass GsfOutfileMSOleClass;
 
 static void
 gsf_outfile_msole_finalize (GObject *obj)
@@ -193,7 +199,9 @@ ole_write_bat (GsfOutput *sink, guint32 block, unsigned blocks)
 {
 	guint8 buf [BAT_INDEX_SIZE];
 
+#ifdef __GNUC__
 #warning optimize this to dump a buffer in 1 step
+#endif
 	while (blocks-- > 1) {
 		block++;
 		GSF_LE_SET_GUINT32 (buf, block);
@@ -295,14 +303,16 @@ gsf_outfile_msole_close (GsfOutput *output)
 
 			memset (buf, 0, DIRENT_SIZE);
 
-			if (i > 0 && /* no name for the root */
-			    gsf_output_name (GSF_OUTPUT (child)) != NULL) {
-			    /* be wary about endianness */
-				gunichar2 *name_utf16 = g_utf8_to_utf16 (
-					gsf_output_name (GSF_OUTPUT (child)),
+			/* Hard code 'Root Entry' for the root */
+			if (i == 0 || gsf_output_name (GSF_OUTPUT (child)) != NULL) {
+				char const *name = (i == 0)
+					? "Root Entry" : gsf_output_name (GSF_OUTPUT (child));
+				gunichar2 *name_utf16 = g_utf8_to_utf16 (name,
 					-1, NULL, &name_len, NULL);
 				if (name_len >= DIRENT_MAX_NAME_SIZE)
 					name_len = DIRENT_MAX_NAME_SIZE-1;
+
+				/* be wary about endianness */
 				for (j = 0 ; j < name_len ; j++)
 					GSF_LE_SET_GUINT16 (buf + j*2, name_utf16 [j]);
 				g_free (name_utf16);
@@ -315,10 +325,13 @@ gsf_outfile_msole_close (GsfOutput *output)
 				GSF_LE_SET_GUINT32 (buf + DIRENT_FIRSTBLOCK,
 					(sb_data_size > 0) ? sb_data_start : BAT_MAGIC_END_OF_CHAIN);
 				GSF_LE_SET_GUINT32 (buf + DIRENT_FILE_SIZE, sb_data_size);
+				memcpy(buf + DIRENT_CLSID, child->clsid, sizeof(child->clsid));
 			} else if (child->type == MSOLE_DIR) {
 				GSF_LE_SET_GUINT8 (buf + DIRENT_TYPE, DIRENT_TYPE_DIR);
 				GSF_LE_SET_GUINT32 (buf + DIRENT_FIRSTBLOCK, DIRENT_MAGIC_END);
 				GSF_LE_SET_GUINT32 (buf + DIRENT_FILE_SIZE, 0);
+				/* write the class id */
+				memcpy(buf + DIRENT_CLSID, child->clsid, sizeof(child->clsid));
 			} else {
 				GSF_LE_SET_GUINT8 (buf + DIRENT_TYPE, DIRENT_TYPE_FILE);
 				GSF_LE_SET_GUINT32 (buf + DIRENT_FIRSTBLOCK, child->first_block);
@@ -576,6 +589,17 @@ ole_name_cmp (GsfOutfileMSOle const *a, GsfOutfileMSOle const *b)
 	}
 }
 
+static void
+gsf_outfile_msole_set_block_size (GsfOutfileMSOle *ole,
+				  unsigned bb_shift, unsigned sb_shift)
+{
+	/* None of these are actually used yet */
+	ole->bb.shift = bb_shift;
+	ole->bb.size  = (1 << ole->bb.shift);
+	ole->sb.shift = sb_shift;
+	ole->bb.size  = (1 << ole->bb.shift);
+}
+
 static GsfOutput *
 gsf_outfile_msole_new_child (GsfOutfile *parent, char const *name,
 			     gboolean is_dir)
@@ -598,6 +622,8 @@ gsf_outfile_msole_new_child (GsfOutfile *parent, char const *name,
 	g_object_ref (G_OBJECT (ole_parent->sink));
 	child->sink   = ole_parent->sink;
 	child->root   = ole_parent->root;
+	gsf_outfile_msole_set_block_size (child,
+		ole_parent->bb.shift, ole_parent->sb.shift); 
 	gsf_output_set_name (GSF_OUTPUT (child), name);
 	gsf_output_set_container (GSF_OUTPUT (child), parent);
 
@@ -617,8 +643,13 @@ gsf_outfile_msole_init (GObject *obj)
 	ole->sink   = NULL;
 	ole->root   = NULL;
 	ole->type   = MSOLE_DIR;
+
+	gsf_outfile_msole_set_block_size (ole, 
+		OLE_DEFAULT_BB_SHIFT, OLE_DEFAULT_SB_SHIFT);
+
 	ole->content.dir.children = NULL;
 	ole->content.dir.root_order = NULL;
+	memset (ole->clsid, 0, sizeof (ole->clsid));
 }
 
 static void
@@ -640,19 +671,24 @@ GSF_CLASS (GsfOutfileMSOle, gsf_outfile_msole,
 	   GSF_OUTFILE_TYPE)
 
 /**
- * gsf_outfile_msole_new :
+ * gsf_outfile_msole_new_full :
  * @sink :
  * @err   :
+ * @bb_shift : the shift size of large blocks
+ * @sb_shift : the shift size of small blocks
  *
  * Creates the root directory of an MS OLE file and manages the addition of
  * children.
  *
  * NOTE : adds a reference to @sink
  *
+ * NOTE the block sizes are still hard coded, so this interface is kept
+ * private.
+ *
  * Returns : the new ole file handler
  **/
-GsfOutfileMSOle *
-gsf_outfile_msole_new (GsfOutput *sink)
+static GsfOutfileMSOle *
+gsf_outfile_msole_new_full (GsfOutput *sink, unsigned bb_shift, unsigned sb_shift)
 {
 	static guint8 const default_header [] = {
 /* 0x00 */	0xd0, 0xcf, 0x11, 0xe0, 0xa1, 0xb1, 0x1a, 0xe1,
@@ -703,6 +739,11 @@ gsf_outfile_msole_new (GsfOutput *sink)
 	ole->content.dir.root_order = g_ptr_array_new ();
 	ole_register_child (ole, ole);
 
+	/*  NOT IMPLEMENTED, DOES NOTHING, as a start we need to validate the
+	 *  values and store them in the header, then we can start worrying
+	 *  about resizing the header block, and storing these in it */
+	gsf_outfile_msole_set_block_size (ole, bb_shift, sb_shift);
+
 	/* The names are the same */
 	gsf_output_set_name (GSF_OUTPUT (ole), gsf_output_name (sink));
 	gsf_output_set_container (GSF_OUTPUT (ole), NULL);
@@ -711,3 +752,39 @@ gsf_outfile_msole_new (GsfOutput *sink)
 
 	return ole;
 }
+
+/**
+ * gsf_outfile_msole_new :
+ * @sink :
+ * @err   :
+ *
+ * Creates the root directory of an MS OLE file and manages the addition of
+ * children.
+ *
+ * NOTE : adds a reference to @sink
+ *
+ * Returns : the new ole file handler
+ **/
+GsfOutfileMSOle *
+gsf_outfile_msole_new (GsfOutput *sink)
+{
+	return gsf_outfile_msole_new_full (sink, 
+		OLE_DEFAULT_SB_SIZE, OLE_DEFAULT_BB_SIZE);
+}
+
+/**
+ * gsf_outfile_msole_set_class_id :
+ * @ole: a #GsfOutfileMSOle
+ * @clsid: 16 byte identifier (often a GUID in MS Windows apps)
+ *
+ * Write @clsid to the directory associated with @ole.
+ *
+ * Returns TRUE on success.
+ **/
+gboolean
+gsf_outfile_msole_set_class_id (GsfOutfileMSOle *ole, guint8 const *clsid)
+{
+	g_return_val_if_fail (ole != NULL && ole->type == MSOLE_DIR, FALSE);
+	memcpy (ole->clsid, clsid, sizeof(ole->clsid));
+	return TRUE;
+}
