@@ -32,8 +32,13 @@ typedef struct _GsfOutfileMSOle GsfOutfileMSOle;
 #define GSF_OUTFILE_MSOLE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GSF_OUTFILE_MSOLE_TYPE, GsfOutfileMSOle))
 #define GSF_IS_OUTFILE_MSOLE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GSF_OUTFILE_MSOLE_TYPE))
 
-GType gsf_outfile_msole_get_type (void);
+#define OLE_DEFAULT_SB_SHIFT	 6
+#define OLE_DEFAULT_BB_SHIFT	 9
+
+GType		 gsf_outfile_msole_get_type (void);
 GsfOutfileMSOle *gsf_outfile_msole_new (GsfOutput *sink);
+gboolean	 gsf_outfile_msole_set_class_id (GsfOutfileMSOle *ole,
+						 guint8 const *clsid);
 
 G_END_DECLS
 
