@@ -2,10 +2,10 @@
 /*
  * gsf-outfile-zip.c: zip archive output.
  *
- * Copyright (C) 2002 Jon K Hellan (hellan@acm.org)
+ * Copyright (C) 2002-2003 Jon K Hellan (hellan@acm.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Outc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -263,7 +263,7 @@ static char *
 stream_name_build (GsfOutfileZip *zip)
 {
 	int namelen = stream_name_len (zip);
-	char *name = g_malloc (namelen + 1);
+	char *name = g_new (char, namelen + 1);
 
 	name[0] = '\0';
 	stream_name_write_to_buf (zip, name, namelen + 1);
@@ -372,7 +372,7 @@ zip_init_write (GsfOutput *output)
 			return FALSE;
 		if (!zip->buf) {
 			zip->buf_size = ZIP_BUF_SIZE;
-			zip->buf = g_malloc (zip->buf_size);
+			zip->buf = g_new (guint8, zip->buf_size);
 		}
 		zip->stream->next_out  = zip->buf;
 		zip->stream->avail_out = zip->buf_size;
@@ -624,7 +624,7 @@ GSF_CLASS (GsfOutfileZip, gsf_outfile_zip,
  *
  * Returns : the new zip file handler
  **/
-GsfOutfile *
+GsfOutfileZip *
 gsf_outfile_zip_new (GsfOutput *sink, G_GNUC_UNUSED GError **err)
 {
 	GsfOutfileZip *zip;
@@ -643,7 +643,7 @@ gsf_outfile_zip_new (GsfOutput *sink, G_GNUC_UNUSED GError **err)
 	gsf_output_set_name (GSF_OUTPUT (zip), gsf_output_name (sink));
 	gsf_output_set_container (GSF_OUTPUT (zip), NULL);
 
-	return GSF_OUTFILE (zip);
+	return zip;
 }
 
 gboolean
