@@ -2,10 +2,10 @@
 /*
  * gsf-output-iochannel.c
  *
- * Copyright (C) 2002 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2002-2003 Dom Lachowicz (cinamod@hotmail.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -37,7 +37,7 @@ typedef struct {
  *
  * Returns a new file or NULL.
  **/
-GsfOutput *
+GsfOutputIOChannel *
 gsf_output_iochannel_new  (GIOChannel * channel)
 {
 	GsfOutputIOChannel *output = NULL;
@@ -46,7 +46,7 @@ gsf_output_iochannel_new  (GIOChannel * channel)
 
 	output = g_object_new (GSF_OUTPUT_IOCHANNEL_TYPE, NULL);	
 	output->channel = channel;
-	return GSF_OUTPUT (output);
+	return output;
 }
 
 static gboolean
