@@ -2,10 +2,10 @@
 /*
  * gsf-output-stdio.c: stdio based output
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -28,12 +28,22 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 
+
 #ifdef G_OS_WIN32
 
+#ifndef S_IRUSR
+#define S_IRUSR 04
+#define S_IWUSR 02
+#define W_OK    00  /* existance mode only */
+typedef int mode_t;
+#endif
+
 #define S_IRGRP S_IRUSR
 #define S_IROTH S_IRUSR
 #define S_ISGID 0
@@ -42,6 +52,10 @@
 #define getgid() 0
 #define chown(filename, uid, gid) 0
 
+#ifdef HAVE_IO_H
+#include <io.h>
+#endif
+
 #endif /* G_OS_WIN32 */
 
 struct _GsfOutputStdio {
@@ -141,7 +155,7 @@ follow_symlinks (char const *filename, GError **error)
  *
  * Returns a new file or NULL.
  **/
-GsfOutput *
+GsfOutputStdio *
 gsf_output_stdio_new (char const *filename, GError **err)
 {
 	GsfOutputStdio *stdio;
@@ -217,7 +231,7 @@ gsf_output_stdio_new (char const *filename, GError **err)
 	stdio->temp_filename = temp_filename;
 	gsf_output_set_name (GSF_OUTPUT (stdio), filename);
 
-	return GSF_OUTPUT (stdio);
+	return stdio;
 
 failure :
 	g_free (temp_filename);
@@ -313,7 +327,7 @@ gsf_output_stdio_seek (GsfOutput *output, gsf_off_t offset, GSeekType whence)
 {
 	GsfOutputStdio const *stdio = GSF_OUTPUT_STDIO (output);
 	int stdio_whence = 0;	/* make compiler shut up */
-	long loffset;
+	gsf_off_t loffset;
 
 	g_return_val_if_fail (stdio->file != NULL, 
 		gsf_output_set_error (output, 0, "missing file"));
