@@ -521,3 +521,47 @@ gsf_output_puts (GsfOutput *output, char const* line)
 	nbytes = strlen (line);
 	return gsf_output_write (output, nbytes, line);
 }
+
+#if 0
+
+#include <gsf/gsf-output-stdio.h>
+#include <gsf/gsf-output-memory.h>
+
+#ifdef HAVE_GNOME
+#include <gsf-gnome/gsf-output-gnomevfs.h>
+#endif
+
+GsfOutput*
+gsf_output_new_for_uri (char const * uri, GError ** err)
+{
+	GsfOutput * output = NULL;
+	size_t len;
+
+	g_return_val_if_fail (uri, NULL);
+
+	len = strlen (uri);
+	g_return_val_if_fail (len, NULL);
+
+	if (len > 3 && !strstr (uri, ":/")) {
+		/* assume plain file */
+		output = GSF_OUTPUT (gsf_output_stdio_new (uri, err));
+	} else if (len >= 6 && !strncmp (uri, "mem://", 6)) {
+		output = GSF_OUTPUT (gsf_output_memory_new ());
+		gsf_output_set_name (output, uri);
+	} else {
+#if HAVE_GNOME
+		/* have gnome, let GnomeVFS deal with this */
+		output = GSF_OUTPUT (gsf_output_gnomevfs_new (uri, err));
+#else
+		if (len > 7 && !strncmp (uri, "file:/", 6)) {
+			/* dumb attempt to translate this into a local path */
+			output = GSF_OUTPUT (gsf_output_stdio_new (uri+7, err));			
+		} 
+		/* else: unknown or unhandled protocol - bail */
+#endif
+	}
+
+	return output;
+}
+
+#endif
