@@ -2,10 +2,10 @@
 /*
  * gsf-structured_blob.c : Utility storage to blob in/out a tree of data
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -138,18 +138,18 @@ blob_name_by_index (GsfInfile *infile, int i)
 }
 
 static GsfInput   *
-blob_child_by_index (GsfInfile *infile, int i)
+blob_child_by_index (GsfInfile *infile, int i, GError **err)
 {
 	GsfStructuredBlob const *blob = (GsfStructuredBlob *) infile;
 	if (blob->children != NULL) {
 		g_return_val_if_fail (i < 0 || (unsigned)i >= blob->children->len, NULL);
-		return gsf_input_dup (g_ptr_array_index (blob->children, i), NULL);
+		return gsf_input_dup (g_ptr_array_index (blob->children, i), err);
 	}
 	return NULL;
 }
 
 static GsfInput   *
-blob_child_by_name (GsfInfile *infile, char const *name)
+blob_child_by_name (GsfInfile *infile, char const *name, GError **err)
 {
 	GsfStructuredBlob const *blob = (GsfStructuredBlob *) infile;
 	if (blob->children != NULL) {
@@ -159,7 +159,7 @@ blob_child_by_name (GsfInfile *infile, char const *name)
 		for (i = 0 ; i < blob->children->len ;) {
 			child = g_ptr_array_index (blob->children, i);
 			if (!strcmp (gsf_input_name (child), name))
-				return gsf_input_dup (child, NULL);
+				return gsf_input_dup (child, err);
 		}
 	}
 	return NULL;
@@ -213,7 +213,7 @@ gsf_structured_blob_read (GsfInput *input)
 
 	content_size = gsf_input_remaining (input);
 	if (content_size > 0) {
-		guint8 *buf = g_try_malloc (content_size);
+		guint8 *buf = (guint8*)g_try_malloc (content_size);
 
 		if (buf == NULL) {
 			g_warning ("Failed attempting to allocate %" GSF_OFF_T_FORMAT " bytes",
