@@ -2,11 +2,11 @@
 /*
  * test-msole1.c: test program to dump biff streams
  *
- * Copyright (C) 2002	Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003	Jody Goldberg (jody@gnome.org)
  * 			Michael Meeks (michael@ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,7 +14,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -27,6 +27,7 @@
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-infile.h>
 #include <gsf/gsf-infile-msole.h>
+#include <gsf/gsf-msole-utils.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -105,14 +106,14 @@ test (int argc, char *argv[])
 {
 	GsfInput  *input, *stream;
 	GsfInfile *infile;
-	GError    *err;
+	GError    *err = NULL;
 	int i;
 	guint16 len, opcode;
 
 	for (i = 1 ; i < argc ; i++) {
 		fprintf( stderr, "%s\n",argv[i]);
 
-		input = gsf_input_mmap_new (argv[i], &err);
+		input = GSF_INPUT (gsf_input_mmap_new (argv[i], &err));
 		if (input == NULL) {
 			g_return_val_if_fail (err != NULL, 1);
 			g_warning ("'%s' error: %s", argv[i], err->message);
@@ -122,7 +123,7 @@ test (int argc, char *argv[])
 
 		input = gsf_input_uncompress (input);
 
-		infile = gsf_infile_msole_new (input, &err);
+		infile = GSF_INFILE (gsf_infile_msole_new (input, &err));
 		if (infile == NULL) {
 
 			g_return_val_if_fail (err != NULL, 1);
@@ -133,6 +134,24 @@ test (int argc, char *argv[])
 			continue;
 		}
 
+		stream = gsf_infile_child_by_name (infile, "\05SummaryInformation");
+		if (stream != NULL) {
+			puts ( "SummaryInfo");
+			gsf_msole_metadata_read (stream, &err);
+			if (err != NULL)
+				g_warning ("'%s' error: %s", argv[i], err->message);
+			g_object_unref (G_OBJECT (stream));
+		}
+
+		stream = gsf_infile_child_by_name (infile, "\05DocumentSummaryInformation");
+		if (stream != NULL) {
+			puts ( "DocSummaryInfo");
+			gsf_msole_metadata_read (stream, &err);
+			if (err != NULL)
+				g_warning ("'%s' error: %s", argv[i], err->message);
+			g_object_unref (G_OBJECT (stream));
+		}
+
 		stream = gsf_infile_child_by_name (infile, "Workbook");
 		if (stream == NULL)
 			stream = gsf_infile_child_by_name (infile, "Book");
